var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
var dotenv = require("dotenv")

var app = express();


dotenv.config({
  path: "./Config/config.env",
})

require("./Config/relation")();

// //Route Files 
var indexRouter = require('./routes/index');
var usersRouter = require('./routes/users');
var authenticationRouter = require('./routes/authentication')
var dbInfoRouter = require('./routes/db')
var itemRouter = require('./routes/item')
var storeRouter = require('./routes/store')
var categoryRouter = require('./routes/category')
var subscriptionRouter = require('./routes/subscription')
var supplierRouter = require('./routes/supplier')
var inventoryRouter = require('./routes/inventory_movement')
var wareouseRouter = require('./routes/warehouse')
var deliveryAddressRouter = require('./routes/delivery_address')


//CORS
var cors = require("cors");

//Body parser
app.use(cors());
app.use(express.json());
app.use(express.urlencoded({
  extended: true
}))


// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'jade');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));
app.use("/uploads", express.static("uploads"));

app.use('/', indexRouter);
app.use('/users', usersRouter);

//Mount Route
app.use("/api/v1/authentication", cors(), authenticationRouter);
app.use("/api/v1/database", dbInfoRouter)
app.use("/api/v1/item", itemRouter)
app.use("/api/v1/store", storeRouter)
app.use("/api/v1/subscriptions", subscriptionRouter)
app.use("/api/v1/category", categoryRouter)
app.use("/api/v1/supplier", supplierRouter)
app.use("/api/v1/inventory", inventoryRouter)
app.use('/api/v1/warehouse', wareouseRouter)
app.use('/api/v1/delivery_address', deliveryAddressRouter)




// catch 404 and forward to error handler
app.use(function (req, res, next) {
  next(createError(404));
});

// error handler
app.use(function (err, req, res, next) {
  console.log("ERROR NAME", err);
  // logger.log({
  //   level: 'info',
  //   message: err.message
  // });
  res.status(err.statusCode || 500).json({
    success: false,
    description: err.message || "Server Error",
  })
});

module.exports = app;
